%DANPLOT:  Extracts and plots radar data
%  
% Instructions: Point and Click
%
% In your home directory
% 1) Create two new directories called dataview and matlab, if they
% don't exist.
% 2) Change to the matlab directory
% 3) Create/modify a file called startup.m so that it includes the following:
%     addpath HOME/matlab/loadchil the dir containing loadchil (see extract.m)
%     addpath HOME/matlab/mex
%     addpath HOME/dataview
%    where HOME is either your home directory (if you actually have the 
%    source files, or is the home directory of someone who has already set
%    things up. Then add
%     addpath <your home dir>/radar
% 4) Copy HOME/dataview/options.m and cases.txt
%    (these are all the host-specific files, I think) to your 
%    radar directory, and modify where appropriate
%
% That should be it. Now, when running Matlab, from any directory typing
% danplot should work.
%
% If you want to tweak any of the files (especially the ones that plot things),
% such as rhiplot.m, copy the original to your radar directory (if you don't 
% have a dataview dir) and tweak away. You might need to type "clear rhiplot"
% or whatever to get Matlab to notice the new version.
%
% Danny Chapman (d.chapman@rdg.ac.uk)

%load in users options from file options.m

danplot_vars;
options;

h=findobj('name','Dappy Danny''s Dodgy Data');
if ~isempty(h)
	delete(h) % we'll only find it if we're running as a callback
else
	close all hidden
end

load colmap;
figure(win_rhiz);
colormap(jet15);
figure(win_ppiz);
colormap(jet15);

%=====================================================================
if (input_case == 1)

	prompt = {'Doppler data file (without .dat extension)                            ','Reflectivity data file (without extension)','Width/velocity data file (without extension)','Force each raster to have multiple scans [0 or 1]'};
	def = {filen,filenz,filenv,corsum};
	filetitle = 'Data Files';
	answer = inputdlg_d(prompt,filetitle,1,def);
	if isempty(answer) == 0
		filen=answer{1};
		filenz=answer{2};
		filenv=answer{3};
		corsum=str2num(answer{3});
	else
		casebrowser
	end
end

sumfont='7x14'; %font to use for summary file
sumfont='6x10';
sumfile=[filen '.sum'];
fname=[filen '.dat'];
fnamez=[filenz '.dat'];
fnamev=[filenv '.dat'];

DX=40;
DY=25;
YOFF=6*DY;

more off;


%colormap(jet(100));
danploth=figure('numbertitle','off','resize','off','name','Dappy Danny''s Dodgy Data','units','pix','position',[5,5,DX*12,YOFF+DY*7],'IntegerHandle','off');

fid= fopen(sumfile);
ta=fgetl(fid);

val=[];
ra=[];
ty=[];
time=[];
date=[];
sc=[];
nums=[];

i=1;
sumi=2;
frewind(fid);
val=fgetl(fid);
sumline=[];
sumline{1}=val;

if val(2:7) == 'pseudo'

	val=fgetl(fid);

	while val ~= -1
		sumline{sumi}=val;
		nums(i)=sumi;
		sumi=sumi+1;
		ra(i)=str2num(val(7:10));
		nscan(i)=str2num(val(12:15));
		if corsum
			nscan(i)=numsum; %for dodgy case...
		end
		sc(i)=1;
		ty(i)=val(34);
		if ty(i)==32
			ty(i)=val(35);
		end
		time(i,:)=val(25:32);
		date(i,:)=val(16:23);
		angle1(i)=NaN;
		angle2(i)=NaN;
		angle3(i)=NaN;
		angle4(i)=NaN;
		
		if nscan(i) > 1
			for j=(i+1):(i+nscan(i)-1),
				sc(j)=j+1-i;
				ra(j)=ra(i);
				nscan(j)=nscan(i);
				ty(j)=ty(i);
				nums(j)=nums(i);
				time(j,:)=time(i,:);
				date(j,:)=date(i,:);
				angle1(j)=angle1(i);
				angle2(j)=angle2(i);
				angle3(j)=angle3(i);
				angle4(j)=angle4(i);
			end
			i=i+nscan(i);
		else
			i=i+1;
		end
		
		val=fgetl(fid);
	end
	
else
	%===============if it's a "proper" summary file============
	val=fgetl(fid);

	while val ~= -1
		sumline{sumi}=val;
		nums(i)=sumi;
		sumi=sumi+1;
		ra(i)=str2num(val(7:9));
		nscan(i)=str2num(val(85:86));
		if corsum
			nscan(i)=numsum; %for dodgy case...
		end
		sc(i)=1;
		ty(i)=val(31);
		time(i,:)=val(11:18);
		date(i,:)=val(20:27);
		angle1(i)=str2num(val(62:66));
		angle2(i)=str2num(val(68:72));;
		angle3(i)=str2num(val(73:78));
		angle4(i)=str2num(val(79:84));
		
		if nscan(i) > 1
			for j=(i+1):(i+nscan(i)-1),
				sc(j)=j+1-i;
				ra(j)=ra(i);
				nscan(j)=nscan(i);
				ty(j)=ty(i);
				time(j,:)=time(i,:);
				date(j,:)=date(i,:);
				nums(j)=nums(i);
				angle1(j)=angle1(i);
				angle2(j)=angle2(i);
				angle3(j)=angle3(i);
				angle4(j)=angle4(i);
			end
			i=i+nscan(i);
		else
			i=i+1;
		end
		
		val=fgetl(fid);
	end

end

fclose(fid);
ns=length(ra);

num=1;
raster=ra(num);

% the summary file...

sumh = uicontrol('Style','listbox','fontname',sumfont,'Position',[0 0 DX*12 YOFF],'String',sumline,'callback','ans=max([1 get(sumh,''value'')]);num=min(find(nums >= ans));,raster=ra(num);,gettext;,set(infoh,''string'',txt);','back',[.9 .9 .9]);
drawnow;
% get the text strings sorted...

gettext;

% do the info/navigation buttons

infoh=uicontrol('max',5,'style','text','fontsize',12,'position',[0,YOFF,4*DX,6*DY],'string',txt,'back','w','fontweight','b');

prevh=uicontrol('Style','Pushbutton','Position',[0,6*DY+YOFF,DX*1.5,DY],'string','Back','callback','num=num-1+(num <= 1);,raster=ra(num);,gettext;,set(infoh,''string'',txt);');

gotoh=uicontrol('Style','edit','Position',[DX*1.5,6*DY+YOFF,DX*1,DY],'string','','callback','answ=str2num(get(gotoh,''string''));,num=min(find(ra >= answ));,raster=ra(num);,gettext;,set(infoh,''string'',txt);,set(gotoh,''string'','''');','back','w','fontsize',12);

nexth=uicontrol('Style','Pushbutton','Position',[2.5*DX,6*DY+YOFF,DX*1.5,DY],'string','Forward','callback','num=num+1-(num >= ns);,raster=ra(num);,gettext;,set(infoh,''string'',txt);');

%===========Doppler stuff...===========
titledh=uicontrol('max',1,'style','text','fontweight','bold','fontsize',14,'position',[4.2*DX,6.1*DY+YOFF,3.6*DX,.8*DY],'string','Doppler','back','w','fore','b');

rhipl2h=uicontrol('Style','Popup','String','RHI:Shear|RHI: Div|RHI:Phi_dp','Position',[4*DX,5*DY+YOFF,2*DX,DY],'Callback','answ=get(rhipl2h,''value'');,if answ == 1; , rhipl2=''sh'';, elseif answ == 2; , rhipl2=''di''; , else, rhipl2=''ph'';,end;');

ppipl2h=uicontrol('Style','Popup','String','PPI: v2|PPI:Phi_dp|PPI:vort|PPI:Kdp','Position',[6*DX,5*DY+YOFF,2*DX,DY],'Callback','answ=get(ppipl2h,''value'');,if answ == 1; , ppipl2=''v2'';, elseif answ == 2;, ppipl2=''ph'';, elseif answ == 3;, ppipl2=''vo'';, elseif answ == 4;, ppipl2=''dp'';,end;');

rhiopts=uicontrol('Style','pushbutton','string','RHI Opts','position',[4*DX,4*DY+YOFF,2*DX,DY],'callback','rhidopopts');

ppiopts=uicontrol('Style','pushbutton','string','PPI Opts','position',[6*DX,4*DY+YOFF,2*DX,DY],'callback','ppidopopts');

plot2h=uicontrol('Style','pushbutton','fontweight','bold','Position',[DX*4,3*DY+YOFF,DX*4,DY],'string','Extract and Plot','callback','set(danploth,''pointer'',''watch'');,drawnow;scan=sc(num);,filename=fname;,extract;,plot_data;,set(danploth,''pointer'',''arrow'');');

plot3h=uicontrol('Style','Pushbutton','Position',[DX*4,2*DY+YOFF,DX*4,DY],'string','Extract only','callback','set(danploth,''pointer'',''watch'');,drawnow;,scan=sc(num);,filename=fname;,extract;,set(danploth,''pointer'',''arrow'');');

%==================reflectivity ones...=================
titlezh=uicontrol('max',1,'style','text','fontweight','bold','fontsize',14,'position',[8.2*DX,6.1*DY+YOFF,3.6*DX,.8*DY],'string','Reflectivity','backg','w','foreg','r');

plz2h=uicontrol('Style','Popup','String','RHI: Zdr|RHI: Ldr','Position',[8*DX,5*DY+YOFF,2*DX,DY],'Callback','answ=get(plz2h,''value'');,if answ == 1; , plz2=''Zdr'';, else, plz2=''Ldr'';,end;');

ppizh=uicontrol('Style','Popup','String','PPI: Zh|PPI: Zdr|PPI: Ldr','Position',[10*DX,5*DY+YOFF,2*DX,DY],'Callback','answ=get(ppizh,''value'');,if answ == 1; , plppiz=''Zh '';, elseif answ == 2; , plppiz=''Zdr''; , else, plppiz=''Ldr'';,end;');

zopts=uicontrol('Style','pushbutton','string','Reflectivity Opts','position',[8*DX,4*DY+YOFF,4*DX,DY],'callback','refopts');

zplot2h=uicontrol('Style','pushbutton','fontweight','bold','Position',[DX*8,3*DY+YOFF,DX*4,DY],'string','Extract and Plot','callback','set(danploth,''pointer'',''watch'');,drawnow;,scan=sc(num);,filename=fnamez;,extract;,;,plot_dataz;,set(danploth,''pointer'',''arrow'');');

zplot3h=uicontrol('Style','Pushbutton','Position',[DX*8,2*DY+YOFF,DX*4,DY],'string','Extract only','callback','set(danploth,''pointer'',''watch'');,drawnow;,scan=sc(num);,filename=fnamez;,extract;,set(danploth,''pointer'',''arrow'');');

%==================Vel/Width ones...=================

if ~isempty(filenv)

	
	set(danploth,'position',[5,5,DX*16,YOFF+DY*7]);
	set(sumh,'Position',[0 0 DX*16 YOFF]);
	titlevh=uicontrol('max',1,'style','text','fontweight','bold','fontsize',14,'position',[12.3*DX,6.1*DY+YOFF,3.6*DX,.8*DY],'string','Vel/Width','backg','w','foreg','g');
	
	plv2h=uicontrol('Style','Popup','String','RHI: v|RHI: shear|RHI: sigma_V|RHI: epsilon','Position',[12*DX,5*DY+YOFF,2*DX,DY],'Callback','answ=get(plv2h,''value'');,if answ == 1; , plv2=''v  '';, elseif answ == 2; , plv2=''sh '';, elseif answ == 3; , plv2=''wiv'';, else, plv2=''eps'';,end;');
	set(plv2h,'value',4)

	ppivh=uicontrol('Style','Popup','String','PPI: v|PPI: width_h|PPI: width_v','Position',[14*DX,5*DY+YOFF,2*DX,DY],'Callback','answ=get(ppivh,''value'');,if answ == 1; , plppiv=''v  '';, elseif answ == 2; , plppiv=''wih''; , else, plppiv=''wiv'';,end;');
	
	vopts=uicontrol('Style','pushbutton','string','Vel/width Opts','position',[12*DX,4*DY+YOFF,4*DX,DY],'callback','velopts');

	vplot2h=uicontrol('Style','pushbutton','fontweight','bold','Position',[DX*12,3*DY+YOFF,DX*4,DY],'string','Extract and Plot','callback','set(danploth,''pointer'',''watch'');,drawnow;,scan=sc(num);,filename=fnamev;,extract;,;,plot_datav;,set(danploth,''pointer'',''arrow'');');

	vplot3h=uicontrol('Style','Pushbutton','Position',[DX*12,2*DY+YOFF,DX*4,DY],'string','Extract only','callback','set(danploth,''pointer'',''watch'');,drawnow;,scan=sc(num);,filename=fnamev;,extract;,set(danploth,''pointer'',''arrow'');');

else
	autoplot_phidp=1; autoplot_width=0;
end

if ~isempty(filenv)
	buttonwidth=12*DX;
else
	buttonwidth=8*DX;
end
plotallh=uicontrol('Style','Pushbutton','Position',[DX*4,1*DY+YOFF,buttonwidth,DY],'string','Extract and plot ALL parameters','callback','allplot');

autoploth=uicontrol('Style','Pushbutton','Position',[DX*4,0*DY+YOFF,buttonwidth,DY],'string','Run the autoplot widget (+allplot options)','callback','autoplot_menu');

clear buttonwidth

%================now set up the menus to enable shortcut keys=============

nav=uimenu('label','Navigate');

uimenu(nav,'label','Forward','callback','num=num+1-(num >= ns);,raster=ra(num);,gettext;,set(infoh,''string'',txt);','accelerator','f');

uimenu(nav,'label','Back','callback','num=num-1+(num <= 1);,raster=ra(num);,gettext;,set(infoh,''string'',txt);','accelerator','b');

ploth=uimenu('label','Plot');

uimenu(ploth,'label','Doppler','callback',get(plot2h,'callback'),'accelerator','d');

uimenu(ploth,'label','Reflectivity','callback',get(zplot2h,'callback'),'accelerator','r');

if ~isempty(filenv)
	uimenu(ploth,'label','Vel/Width','callback',get(vplot2h,'callback'),'accelerator','v');
end

uimenu(ploth,'label','All parameters','callback','allplot','accelerator','a');

newh=uimenu('label','New');

uimenu(newh,'label','New File','callback','danplot');

set(danploth,'handlevis','callback');