% vad/calc_all: calculates/plots a time-series of VAD-derived profiles

% the numbers below define the start and end of each collection of
% scans. note that to get the number of, say, raster 3, scan 2, find
% it using danplot, then look at the value of the num variable.

nums_min=[1, 22,43,64,85, 106,127,150];
nums_max=[20,41,62,83,104,125,146,168];

num_seq=length(nums_min);

if 1 % change this to either calculate the data, or load it from a
     % previous go
	clear mean_times;
	for count=1:num_seq
		
		num_min=nums_min(count);
		num_max=nums_max(count);
		
		autoplot;% do some calculations
		mean_times(count)=mean(all_times)
		%	disp('hit a key...')
		%	pause
		
		%	index=find(isnan(vel_all));
		%	vel_all(index)=0;
		%	weight_all(index)=0;
		
		%unfold vel_all
		
		diff_vel=diff(vel_all);
		
		mean_diff=[];
		for i=1:size(vel_all,1)-1
			index=find(finite(diff_vel(i,:)));
			
			mean_diff(i)=sum(diff_vel(i,index))/length(index);
		end
		
		for i=1:size(vel_all,1)-1
			if mean_diff(i)>15
				vel_all((i+1):end,:)=vel_all((i+1):end,:)-30;
			elseif mean_diff(i)<-15
				vel_all((i+1):end,:)=vel_all((i+1):end,:)+30;
			end
		end
		figure(35)
		pcolor(vel_all');
		
		%calculate vad parameters using the mkhodo script
		figure(21)
		mkhodo
		
		if (count == 1)
			hodo_u_all=u;
			hodo_v_all=v;
		else
			hodo_u_all(count,:)=u;
			hodo_v_all(count,:)=v;
			
			figure(25)
			pcolor(mean_times,zr-dz/2,hodo_u_all')
			title('u')
			colorbar
			
			figure(26)
			pcolor(mean_times,zr-dz/2,hodo_v_all')
			title('v')
			colorbar
			
			v_sh=gradient(hodo_v_all,dz);
			u_sh=gradient(hodo_u_all,dz);
			sh_total=(v_sh.^2 + u_sh.^2).^0.5;
			figure(27)
			pcolor(mean_times,zr-dz/2,sh_total')               
			shading interp
			colorbar
			title('Shear')
			
		end
	end
else
	load vad_30_slope_nomask.mat
end

dz1=0.05
[t1,z1]=meshgrid(min(mean_times):0.02:max(mean_times),min(zr):dz1:max(zr));
u_vel1=interp2(mean_times,zr,hodo_u_all',t1,z1,'*linear');
v_vel1=interp2(mean_times,zr,hodo_v_all',t1,z1,'*linear');
sh1=interp2(mean_times,zr,sh_total',t1,z1,'*linear');

desc_txt=' (xmax=30, slope correction, no masking)';

figure(50)
clf
[c,h,cf]=contourf(t1,z1,u_vel1,floor(min(u_vel1(:))):2:ceil(max(u_vel1(:))),'w');
set(gca,'xdir','rev')
clabel(c,h,'labels',288) 
%colorbar
xlabel('Time (UTC)')
ylabel('Height (km)')
title(['Time-height section of u' desc_txt])

figure(51)
clf
[c,h,cf]=contourf(t1,z1,v_vel1,floor(min(v_vel1(:))):2:ceil(max(v_vel1(:))),'w');
set(gca,'xdir','rev')
clabel(c,h,'labels',288) 
%colorbar
xlabel('Time (UTC)')
ylabel('Height (km)')
title(['Time-height section of v' desc_txt])

figure(52)
clf
[c,h,cf]=contourf(t1,z1,sh1,floor(min(sh1(:))):2:ceil(max(sh1(:))),'w');
set(gca,'xdir','rev')
%colorbar
clabel(c,h,'labels',288) 
xlabel('Time (UTC)')
ylabel('Height (km)')
title(['Time-height section of shear' desc_txt])

figure(53)
clf
for i=1:8
	subplot(2,4,i),plot(hodo_u_all(i,:),hodo_v_all(i,:),'-x')
	axis equal
	grid on
	hold on
	plot(0,0,'*')
	plot(hodo_u_all(i,1:5:end),hodo_v_all(i,1:5:end),'o');
	title(['Hodograph: Time=' num2str(i)])
end

%======================================================================
%  Calculate and plot wind components parallel/perpendicular to front  
%======================================================================

speed_all=sqrt(u_vel1.^2 + v_vel1.^2);
dir_all=atan2(u_vel1,v_vel1);

this_dir=45*pi/180; %+ve to the NE
v_par=speed_all.*cos(this_dir-dir_all);
this_dir=135*pi/180; %+ve to the SE
v_perp=speed_all.*cos(this_dir-dir_all);

[junk sh_par]=gradient(v_par,dz1);
[junk sh_perp]=gradient(v_perp,dz1);

figure(54)
clf
[c,h,cf]=contourf(t1,z1,v_par,floor(min(v_par(:))):2:ceil(max(v_par(:))),'w');
set(gca,'xdir','rev')
clabel(c,h,'labels',288) 
%colorbar
xlabel('Time (UTC)')
ylabel('Height (km)')
title(['Time-height section of v\_par' desc_txt])

figure(55)
clf
[c,h,cf]=contourf(t1,z1,v_perp,floor(min(v_perp(:))):2:ceil(max(v_perp(:))),'w');
set(gca,'xdir','rev')
clabel(c,h,'labels',288) 
colorbar
xlabel('Time (UTC)')
ylabel('Height (km)')
title(['Time-height section of v\_perp' desc_txt])

figure(56)
clf
[c,h,cf]=contourf(t1,z1,smooth2d(sh_par,1,1),floor(min(sh_par(:))):2:ceil(max(sh_par(:))),'w');
set(gca,'xdir','rev')
clabel(c,h,'labels',288) 
%colorbar
xlabel('Time (UTC)')
ylabel('Height (km)')
title(['Time-height section of sh\_par' desc_txt])

figure(57)
clf
[c,h,cf]=contourf(t1,z1,smooth2d(sh_perp,1,1),floor(min(sh_perp(:))):2:ceil(max(sh_perp(:))),'w');
set(gca,'xdir','rev')
clabel(c,h,'labels',288) 
%colorbar
xlabel('Time (UTC)')
ylabel('Height (km)')
title(['Time-height section of sh\_perp' desc_txt])

if 0
	figure(52);axis([6 15 0 5]);set(gca,'position',[.1,.25,.8,.65]);set(gcf,'paperunits','centimeters','paperposition',[2,8,17,17]); printcol
%	figure(54);axis([6 15 0 5]);set(gca,'position',[.1,.25,.8,.65]);set(gcf,'paperunits','centimeters','paperposition',[2,8,17,17]); printcol
	figure(55);axis([6 15 0 5]);set(gca,'position',[.1,.25,.8,.65]);set(gcf,'paperunits','centimeters','paperposition',[2,8,17,17]); printcol
	figure(56);axis([6 15 0 5]);set(gca,'position',[.1,.25,.8,.65]);set(gcf,'paperunits','centimeters','paperposition',[2,8,17,17]); printcol
	figure(57);axis([6 15 0 5]);set(gca,'position',[.1,.25,.8,.65]);set(gcf,'paperunits','centimeters','paperposition',[2,8,17,17]); printcol
end
	

